==> liblwgeom-2.5.0-1-src.tar.bz2: osgeo4w/package.sh <==
export P=liblwgeom
export V=2.5.0
export B=1
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f postgis-$V.tar.gz ] || wget https://download.osgeo.org/postgis/source/postgis-$V.tar.gz
if ! [ -d ../liblwgeom ]; then
	tar -C .. -xzf postgis-$V.tar.gz postgis-$V/postgis_svn_revision.h postgis-$V/liblwgeom postgis-$V/COPYING --xform s,postgis-$V,.,
       
	cp makefile.vc ../liblwgeom
	cp postgis_config.h.vc ../postgis_config.h
	cp liblwgeom.h.vc ../liblwgeom/liblwgeom.h

	patch -p2 -d ../liblwgeom <liblwgeom.diff
fi

if ! [ -d "$OSGEO4W_REP" ]; then
	echo no repository
	exit 1
fi

fetchenv() {
	local IFS
	IFS=
	batch=$1
	shift

	if ! [ -f "$batch" ]; then
		echo "$batch not found"
		return 1
	fi

	srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
	dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
	diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
	envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
	cmd /c set >$srcenv
	cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
	/usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
	s/\\\\/\\//g;
	s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
	s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
	/usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
	. $diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			;;

		*)
			echo invalid arch
			exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R/$P-devel

		cat <<EOF >$R/setup.hint
sdesc: "liblwgeom"
ldesc: "liblwgeom"
category: Libs
maintainer: $MAINTAINER
requires: msvc2015 geos proj
EOF

		cp ../COPYING $R/$P-$V-$B.txt

		fetchenv "$OSGEO4W_ROOT/bin/o4w_env.bat"
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH
		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:$PATH:/bin"

		cd ../liblwgeom

		export INCLUDE="$(cygpath -m $OSGEO4W_ROOT/include);$INCLUDE"
		export LIB="$(cygpath -m $OSGEO4W_ROOT/lib);$LIB"

		nmake /f makefile.vc clean
		nmake /f makefile.vc

		cd ../osgeo4w

		/bin/tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 \
			osgeo4w/liblwgeom.diff \
			osgeo4w/liblwgeom.h.vc \
			osgeo4w/makefile.vc \
			osgeo4w/package.sh \
			osgeo4w/postgis_config.h.vc \
			osgeo4w/unistd.h

		/bin/tar -cjf $R/$P-$V-$B.tar.bz2 \
			--absolute-names \
			--xform s,../liblwgeom/lwgeom.dll,bin/lwgeom.dll, \
			--xform s,../liblwgeom/lwgeom.lib,lib/lwgeom.lib, \
			--xform s,../liblwgeom/lwgeom_i.lib,lib/lwgeom_i.lib, \
			--xform s,../liblwgeom/liblwgeom.h,include/liblwgeom.h, \
			../liblwgeom/lwgeom.dll \
			../liblwgeom/lwgeom.lib \
			../liblwgeom/lwgeom_i.lib \
			../liblwgeom/liblwgeom.h
	)
done

date

==> liblwgeom-3.0.0-1-src.tar.bz2: osgeo4w/package.sh <==
export P=liblwgeom
export V=3.0.0
export B=1
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f postgis-$V.tar.gz ] || wget https://download.osgeo.org/postgis/source/postgis-$V.tar.gz
if ! [ -d ../liblwgeom ]; then
	tar -C .. -xzf postgis-$V.tar.gz postgis-$V/postgis_svn_revision.h postgis-$V/liblwgeom postgis-$V/COPYING --xform s,postgis-$V,.,
	patch -p3 -d .. <liblwgeom.diff
fi

if ! [ -d "$OSGEO4W_REP" ]; then
	echo no repository
	exit 1
fi

fetchenv() {
	local IFS
	IFS=
	batch=$1
	shift

	if ! [ -f "$batch" ]; then
		echo "$batch not found"
		return 1
	fi

	srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
	dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
	diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
	envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
	cmd /c set >$srcenv
	cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
	/usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
	s/\\\\/\\//g;
	s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
	s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
	/usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
	. $diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			;;

		*)
			echo invalid arch
			exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R/$P-devel

		cat <<EOF >$R/setup.hint
sdesc: "liblwgeom"
ldesc: "liblwgeom"
category: Libs
maintainer: $MAINTAINER
requires: msvc2015 geos proj
EOF

		cp ../COPYING $R/$P-$V-$B.txt

		fetchenv "$OSGEO4W_ROOT/bin/o4w_env.bat"
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH
		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:$PATH:/bin"

		cd ../liblwgeom

		export INCLUDE="$(cygpath -m $OSGEO4W_ROOT/include);$INCLUDE"
		export LIB="$(cygpath -m $OSGEO4W_ROOT/lib);$LIB"

		nmake /f makefile.vc clean
		nmake /f makefile.vc

		cd ../osgeo4w

		/bin/tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 \
			osgeo4w/liblwgeom.diff \
			osgeo4w/package.sh \
			osgeo4w/unistd.h

		/bin/tar -cjf $R/$P-$V-$B.tar.bz2 \
			--absolute-names \
			--xform s,../liblwgeom/lwgeom.dll,bin/lwgeom.dll, \
			--xform s,../liblwgeom/lwgeom.lib,lib/lwgeom.lib, \
			--xform s,../liblwgeom/lwgeom_i.lib,lib/lwgeom_i.lib, \
			--xform s,../liblwgeom/liblwgeom.h,include/liblwgeom.h, \
			--xform s,../liblwgeom/lwinline.h,include/lwinline.h, \
			../liblwgeom/lwgeom.dll \
			../liblwgeom/lwgeom.lib \
			../liblwgeom/lwgeom_i.lib \
			../liblwgeom/liblwgeom.h \
			../liblwgeom/lwinline.h
	)
done

date
